@@ -1,5 +1,5 @@
 /* This file is part of the 'stringi' package for R.
- * Copyright (c) 2013-2014, Marek Gagolewski and Bartek Tartanus
+ * Copyright (c) 2013-2017, Marek Gagolewski and other contributors.
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -66,6 +66,14 @@ SEXP stri_enc_set(SEXP enc)
    // get "official" encoding name:
    const char* name = ucnv_getName(uconv, &status);
    STRI__CHECKICUSTATUS_THROW(status, {/* do nothing special on err */})
+
+   /*
+    DO NOT call this function when ANY ICU function is being used
+    from more than one thread! This function sets the current default
+    converter name. If this function needs to be called, it should be
+    called during application initialization.
+    Do not use unless you know what you are doing.
+    */
    ucnv_setDefaultName(name); // set as default
 
    return R_NilValue;
@@ -191,11 +199,11 @@ SEXP stri_enc_info(SEXP enc)
       Rf_warning(MSG__ENC_ERROR_GETNAME);
    }
    else {
-      SET_VECTOR_ELT(vals, 1, Rf_mkString(canname));
+      SET_VECTOR_ELT(vals, 1, stri__make_character_vector_char_ptr(1, canname));
 
       // friendly name
       const char* frname = StriUcnv::getFriendlyName(canname);
-      if (frname)  SET_VECTOR_ELT(vals, 0, Rf_mkString(frname));
+      if (frname)  SET_VECTOR_ELT(vals, 0, stri__make_character_vector_char_ptr(1, frname));
       else         SET_VECTOR_ELT(vals, 0, Rf_ScalarString(NA_STRING));
 
       // has ASCII as its subset?
@@ -224,7 +232,7 @@ SEXP stri_enc_info(SEXP enc)
          if (U_FAILURE(status) || !stdname)
             SET_VECTOR_ELT(vals, i+2, Rf_ScalarString(NA_STRING));
          else
-            SET_VECTOR_ELT(vals, i+2, Rf_mkString(stdname));
+            SET_VECTOR_ELT(vals, i+2, stri__make_character_vector_char_ptr(1, stdname));
       }
    }
    Rf_setAttrib(vals, R_NamesSymbol, names);
